@@ -5,64 +5,11 @@ import json
 from .data.meat import dictionary as meat_dictionary
 from .data.ingredients import dictionary as ing_dictionary
 import inflect
+from unidecode import unidecode
 
 engine = inflect.engine()
 
 
-# def average_recipe(phrases, df_recipes, df):
-#     phrases = [phrases] if isinstance(phrases, str) else phrases
-
-#     composed_recipe = pd.DataFrame(columns=["ingredient", "per_serving"])
-
-#     for phrase in phrases:
-#         phrase = phrase.lower()
-#         titles = [
-#             title for title in df_recipes["Recipe_title"] if phrase in title.lower()
-#         ]
-#         ids = df_recipes[df_recipes["Recipe_title"].isin(titles)]["Recipe_id"].values
-#         print(f"Number of {phrase} recipes:", len(titles))
-
-#         subset = (
-#             df[df["recipe_no"].isin(ids)]
-#             .groupby(["recipe_no", "ingredient"])
-#             .sum()["p_s"]
-#             .reset_index()
-#         )
-#         subset["%_of_recipes"] = 0
-#         percentage_of_recipes = (
-#             subset.groupby("ingredient")
-#             .count()["%_of_recipes"]
-#             .apply(lambda x: x / len(ids))
-#         )
-#         subset = pd.concat(
-#             [subset.groupby("ingredient").mean()["p_s"], percentage_of_recipes], axis=1
-#         )
-#         subset = subset[subset["%_of_recipes"] > 0.20].sort_values(
-#             "%_of_recipes", ascending=False
-#         )
-#         composed_recipe = composed_recipe.append(
-#             pd.DataFrame(
-#                 data={"ingredient": subset.index, "per_serving": subset["p_s"]}
-#             )
-#         )
-#     #         return subset[subset['%_of_recipes']>.20].sort_values('%_of_recipes', ascending=False)
-
-#     return composed_recipe.groupby("ingredient").sum()
-
-
-# def predict_region(tags, clf, df_recipes, df, columns):
-#     avg_recipe = average_recipe(tags, df_recipes, df)
-#     onehot_data = recipe_to_onehot(ings=avg_recipe, columns=columns, num=1000)
-#     prediction = clf.predict_proba(onehot_data.values)
-
-#     return pd.DataFrame(
-#         data={"Probability": [prob for prob in prediction[0]]},
-#         index=[reg for reg in clf.le.classes_],
-#     )
-#     # for reg, prob in zip(clf.le.classes_, prediction[0]):
-#     #     print(reg, prob)
-
-
 def read_json(path):
     file = open(path)
     content = json.load(file)
@@ -125,7 +72,7 @@ def get_soups():
 
 
 def get_pasta():
-    return ing_dictionary['pasta']
+    return ing_dictionary["pasta"]
 
 
 def get_meats():
@@ -165,6 +112,7 @@ def get_lean_fish():
         "tilapia",
     ]
 
+
 #
 # THIS GOES ON THE REAL REAL
 #
@@ -175,6 +123,7 @@ from .data.meat import dictionary as dict_meat
 from .data.ingredients import dictionary as dict_ing
 from .data.constants import u_substitutions, n_substitutions, s_substitutions
 import re
+
 # from tokenizers import normalizers, Regex
 # from tokenizers.normalizers import NFD, StripAccents, Replace, Sequence, Strip, Lowercase
 
@@ -391,7 +340,9 @@ def I_to_singular(ingredient):
 
 
 def I_to_singular_nlp(ingredient):
-    return ' '.join([t.text if t.tag_ not in ['NNS', 'NNPS'] else t.lemma_ for t in nlp(ingredient)])
+    return " ".join(
+        [t.text if t.tag_ not in ["NNS", "NNPS"] else t.lemma_ for t in nlp(ingredient)]
+    )
 
 
 def P_filter(phrase):
@@ -468,4 +419,44 @@ def ingredient_fixer(ingredient, morequent_ingredients):
     elif most_frequent_match:
         return most_frequent_match
     else:
-        return ingredient
\ No newline at end of file
+        return ingredient
+
+
+def plural(label_list):
+    return [engine.plural_noun(e) for e in label_list if engine.plural_noun(e)]
+
+
+def with_plural(label_list):
+    return label_list + plural(label_list)
+
+
+def to_regex(label_list):
+    return rf"(?:\b(?:{r'|'.join(label_list)})\b)"
+
+
+def squish_multi_bracket(text):
+    text = re.sub(r"\({3}([^\(]*)\){3}", r"(\1)", text)
+    return re.sub(r"\({2}([^\(]*)\){2}", r"(\1)", text)
+
+
+def rm_nested_bracket(text):
+    text = re.sub(r"\([^()]*\)", r"", text)
+    return text
+
+
+def get_bracket_content(text):
+    return list(re.findall(r"\((.*)\)", text))
+
+
+def rm_bracket_content(text):
+    return re.sub(r"\(.*\)", "", text)
+
+
+def rm_roman_numerals(text):
+    roman_numerals = r"(?=[MDCLXVI])M*(C[MD]|D?C{0,3})(X[CL]|L?X{0,3})(I[XV]|V?I{0,3})$"
+
+    return re.sub(roman_numerals, "", text)
+
+
+def rm_accent(text):
+    return unidecode(text)
